@@ -298,6 +298,8 @@ class _Sections(object):
       Cloud SDK.
     lifesciences: Section, The section containing lifesciencs properties for the
       Cloud SDK.
+    memcache: Section, The section containing memcache properties for the Cloud
+      SDK.
     metrics: Section, The section containing metrics properties for the Cloud
       SDK.
     ml_engine: Section, The section containing ml_engine properties for the
@@ -358,6 +360,7 @@ class _Sections(object):
     self.healthcare = _SectionHealthcare()
     self.interactive = _SectionInteractive()
     self.lifesciences = _SectionLifeSciences()
+    self.memcache = _SectionMemcache()
     self.metrics = _SectionMetrics()
     self.ml_engine = _SectionMlEngine()
     self.notebooks = _SectionNotebooks()
@@ -404,6 +407,7 @@ class _Sections(object):
         self.healthcare,
         self.interactive,
         self.lifesciences,
+        self.memcache,
         self.metrics,
         self.ml_engine,
         self.notebooks,
@@ -1860,6 +1864,9 @@ class _SectionApiClientOverrides(_Section):
     self.appengine = self._Add('appengine')
     self.cloudidentity = self._Add('cloudidentity')
     self.compute = self._Add('compute')
+    self.compute_alpha = self._Add('compute/alpha')
+    self.compute_beta = self._Add('compute/beta')
+    self.compute_v1 = self._Add('compute/v1')
     self.container = self._Add('container')
     self.speech = self._Add('speech')
     self.sql = self._Add('sql')
@@ -1931,6 +1938,18 @@ class _SectionContextAware(_Section):
         hidden=True)
 
 
+class _SectionMemcache(_Section):
+  """Contains the properties for the 'memcache' section."""
+
+  def __init__(self):
+    super(_SectionMemcache, self).__init__('memcache')
+    self.region = self._Add(
+        'region',
+        help_text='Default region to use when working with Cloud Memorystore '
+        'for Memcached resources. When a `region` is required but not provided '
+        'by a flag, the command will fall back to this value, if set.')
+
+
 class _SectionRedis(_Section):
   """Contains the properties for the 'redis' section."""
 
